aboutsummaryrefslogtreecommitdiffstats
path: root/simulation
diff options
context:
space:
mode:
authorMission Liao <mission.liao@dexon.org>2018-10-02 15:45:29 +0800
committerGitHub <noreply@github.com>2018-10-02 15:45:29 +0800
commitfb27745f2ca4eaf66f53f48740cbd148ee15bbdf (patch)
tree1b706c5a93a4f09f27d2bc729cf55c5d4f0b5aaa /simulation
parentd7f6db871180b53548aed6a5450e1c5879c90b04 (diff)
downloaddexon-consensus-fb27745f2ca4eaf66f53f48740cbd148ee15bbdf.tar
dexon-consensus-fb27745f2ca4eaf66f53f48740cbd148ee15bbdf.tar.gz
dexon-consensus-fb27745f2ca4eaf66f53f48740cbd148ee15bbdf.tar.bz2
dexon-consensus-fb27745f2ca4eaf66f53f48740cbd148ee15bbdf.tar.lz
dexon-consensus-fb27745f2ca4eaf66f53f48740cbd148ee15bbdf.tar.xz
dexon-consensus-fb27745f2ca4eaf66f53f48740cbd148ee15bbdf.tar.zst
dexon-consensus-fb27745f2ca4eaf66f53f48740cbd148ee15bbdf.zip
core: replace reliable-broadcast with shard (#159)
Diffstat (limited to 'simulation')
-rw-r--r--simulation/governance.go12
1 files changed, 6 insertions, 6 deletions
diff --git a/simulation/governance.go b/simulation/governance.go
index 8b6c3e5..8a83feb 100644
--- a/simulation/governance.go
+++ b/simulation/governance.go
@@ -78,8 +78,8 @@ func (g *simGovernance) setNetwork(network *network) {
g.network = network
}
-// GetNodeSet returns the current notary set.
-func (g *simGovernance) GetNodeSet(round uint64) (ret []crypto.PublicKey) {
+// NodeSet returns the current notary set.
+func (g *simGovernance) NodeSet(round uint64) (ret []crypto.PublicKey) {
g.lock.RLock()
defer g.lock.RUnlock()
@@ -89,8 +89,8 @@ func (g *simGovernance) GetNodeSet(round uint64) (ret []crypto.PublicKey) {
return
}
-// GetConfiguration returns the configuration at a given round.
-func (g *simGovernance) GetConfiguration(round uint64) *types.Config {
+// Configuration returns the configuration at a given round.
+func (g *simGovernance) Configuration(round uint64) *types.Config {
return &types.Config{
NumShards: 1,
NumChains: g.chainNum,
@@ -107,8 +107,8 @@ func (g *simGovernance) GetConfiguration(round uint64) *types.Config {
}
}
-// GetCRS returns the CRS for a given round.
-func (g *simGovernance) GetCRS(round uint64) common.Hash {
+// CRS returns the CRS for a given round.
+func (g *simGovernance) CRS(round uint64) common.Hash {
return g.crs[round]
}